package com.ruoyi.system.controller;

import com.ruoyi.system.api.domain.SysDept;
import com.ruoyi.system.domain.SysUserRole;
import com.ruoyi.system.api.domain.SysUser;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PutMapping;
import com.ruoyi.common.security.utils.SecurityUtils;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.validation.annotation.Validated;
import com.ruoyi.common.core.web.domain.AjaxResult;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import javax.servlet.http.HttpServletResponse;
import org.springframework.web.bind.annotation.GetMapping;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import java.util.List;
import com.ruoyi.common.core.web.page.TableDataInfo;
import com.ruoyi.system.api.domain.SysRole;
import com.ruoyi.system.service.ISysDeptService;
import com.ruoyi.system.service.ISysUserService;
import org.springframework.beans.factory.annotation.Autowired;
import com.ruoyi.system.service.ISysRoleService;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.core.web.controller.BaseController;

@RestController
@RequestMapping({ "/role" })
public class SysRoleController extends BaseController
{
    @Autowired
    private ISysRoleService roleService;
    @Autowired
    private ISysUserService userService;
    @Autowired
    private ISysDeptService deptService;
    
    @RequiresPermissions({ "system:role:list" })
    @GetMapping({ "/list" })
    public TableDataInfo list(final SysRole role) {
        this.startPage();
        final List<SysRole> list = this.roleService.selectRoleList(role);
        return this.getDataTable((List)list);
    }
    
    @Log(title = "角色管理", businessType = BusinessType.EXPORT)
    @RequiresPermissions({ "system:role:export" })
    @PostMapping({ "/export" })
    public void export(final HttpServletResponse response, final SysRole role) {
        final List<SysRole> list = this.roleService.selectRoleList(role);
        final ExcelUtil<SysRole> util = (ExcelUtil<SysRole>)new ExcelUtil((Class)SysRole.class);
        util.exportExcel(response, (List)list, "角色数据");
    }
    
    @RequiresPermissions({ "system:role:query" })
    @GetMapping({ "/{roleId}" })
    public AjaxResult getInfo(@PathVariable final Long roleId) {
        this.roleService.checkRoleDataScope(new Long[] { roleId });
        return this.success((Object)this.roleService.selectRoleById(roleId));
    }
    
    @RequiresPermissions({ "system:role:add" })
    @Log(title = "角色管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@Validated @RequestBody final SysRole role) {
        if (!this.roleService.checkRoleNameUnique(role)) {
            return this.error("新增角色'" + role.getRoleName() + "'失败，角色名称已存在");
        }
        if (!this.roleService.checkRoleKeyUnique(role)) {
            return this.error("新增角色'" + role.getRoleName() + "'失败，角色权限已存在");
        }
        role.setCreateBy(SecurityUtils.getUsername());
        return this.toAjax(this.roleService.insertRole(role));
    }
    
    @RequiresPermissions({ "system:role:edit" })
    @Log(title = "角色管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@Validated @RequestBody final SysRole role) {
        this.roleService.checkRoleAllowed(role);
        this.roleService.checkRoleDataScope(new Long[] { role.getRoleId() });
        if (!this.roleService.checkRoleNameUnique(role)) {
            return this.error("修改角色'" + role.getRoleName() + "'失败，角色名称已存在");
        }
        if (!this.roleService.checkRoleKeyUnique(role)) {
            return this.error("修改角色'" + role.getRoleName() + "'失败，角色权限已存在");
        }
        role.setUpdateBy(SecurityUtils.getUsername());
        return this.toAjax(this.roleService.updateRole(role));
    }
    
    @RequiresPermissions({ "system:role:edit" })
    @Log(title = "角色管理", businessType = BusinessType.UPDATE)
    @PutMapping({ "/dataScope" })
    public AjaxResult dataScope(@RequestBody final SysRole role) {
        this.roleService.checkRoleAllowed(role);
        this.roleService.checkRoleDataScope(new Long[] { role.getRoleId() });
        return this.toAjax(this.roleService.authDataScope(role));
    }
    
    @RequiresPermissions({ "system:role:edit" })
    @Log(title = "角色管理", businessType = BusinessType.UPDATE)
    @PutMapping({ "/changeStatus" })
    public AjaxResult changeStatus(@RequestBody final SysRole role) {
        this.roleService.checkRoleAllowed(role);
        this.roleService.checkRoleDataScope(new Long[] { role.getRoleId() });
        role.setUpdateBy(SecurityUtils.getUsername());
        return this.toAjax(this.roleService.updateRoleStatus(role));
    }
    
    @RequiresPermissions({ "system:role:remove" })
    @Log(title = "角色管理", businessType = BusinessType.DELETE)
    @DeleteMapping({ "/{roleIds}" })
    public AjaxResult remove(@PathVariable final Long[] roleIds) {
        return this.toAjax(this.roleService.deleteRoleByIds(roleIds));
    }
    
    @RequiresPermissions({ "system:role:query" })
    @GetMapping({ "/optionselect" })
    public AjaxResult optionselect() {
        return this.success((Object)this.roleService.selectRoleAll());
    }
    
    @RequiresPermissions({ "system:role:list" })
    @GetMapping({ "/authUser/allocatedList" })
    public TableDataInfo allocatedList(final SysUser user) {
        this.startPage();
        final List<SysUser> list = this.userService.selectAllocatedList(user);
        return this.getDataTable((List)list);
    }
    
    @RequiresPermissions({ "system:role:list" })
    @GetMapping({ "/authUser/unallocatedList" })
    public TableDataInfo unallocatedList(final SysUser user) {
        this.startPage();
        final List<SysUser> list = this.userService.selectUnallocatedList(user);
        return this.getDataTable((List)list);
    }
    
    @RequiresPermissions({ "system:role:edit" })
    @Log(title = "角色管理", businessType = BusinessType.GRANT)
    @PutMapping({ "/authUser/cancel" })
    public AjaxResult cancelAuthUser(@RequestBody final SysUserRole userRole) {
        return this.toAjax(this.roleService.deleteAuthUser(userRole));
    }
    
    @RequiresPermissions({ "system:role:edit" })
    @Log(title = "角色管理", businessType = BusinessType.GRANT)
    @PutMapping({ "/authUser/cancelAll" })
    public AjaxResult cancelAuthUserAll(final Long roleId, final Long[] userIds) {
        return this.toAjax(this.roleService.deleteAuthUsers(roleId, userIds));
    }
    
    @RequiresPermissions({ "system:role:edit" })
    @Log(title = "角色管理", businessType = BusinessType.GRANT)
    @PutMapping({ "/authUser/selectAll" })
    public AjaxResult selectAuthUserAll(final Long roleId, final Long[] userIds) {
        this.roleService.checkRoleDataScope(new Long[] { roleId });
        return this.toAjax(this.roleService.insertAuthUsers(roleId, userIds));
    }
    
    @RequiresPermissions({ "system:role:query" })
    @GetMapping({ "/deptTree/{roleId}" })
    public AjaxResult deptTree(@PathVariable("roleId") final Long roleId) {
        final AjaxResult ajax = AjaxResult.success();
        ajax.put("checkedKeys", (Object)this.deptService.selectDeptListByRoleId(roleId));
        ajax.put("depts", (Object)this.deptService.selectDeptTreeList(new SysDept()));
        return ajax;
    }
}
